[banner goes here]

[Badges for pypi version (0.1.0), crates version (0.1.0), python versions supported (3.8-3.12), code style (black), license (MIT), tests (passing), perhaps a doi eventually]

# ```chemonaut```: An open-source library for exploring chemical and reaction space

## Create molecular simulation and machine learning workflows to predict chemical properties and reactivity.

```bash
pip install chemonaut
```

Some example code:

```python
import chemonaut as cn
# example python code
```